/* -*- Mode: js; indent-tabs-mode: nil; js-basic-offset: 4; tab-width: 4; -*- */
/*
 * This file is part of Looking Glass Button.
 *
 * extension.js
 *
 * Copyright (c) 2019 Gianni Lerro {glerro} ~ <glerro@pm.me>
 *
 * Looking Glass Button is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Looking Glass Button is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with Looking Glass Button. If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

'use strict';

const Gio = imports.gi.Gio;
const GObject = imports.gi.GObject;
const St = imports.gi.St;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Main = imports.ui.main;
const PanelMenu = imports.ui.panelMenu;

// For compatibility checks, as described above
const Config = imports.misc.config;
const SHELL_MINOR = parseInt(Config.PACKAGE_VERSION.split('.')[1]);


// Extend the Button class from Panel Menu.
var LGIndicator = class LGIndicator extends PanelMenu.Button {
    _init() {
        super._init(0.0, `${Me.metadata.name} Indicator`, false);

        // Pick an icon
        let icon = new St.Icon({
            gicon: new Gio.ThemedIcon({ name: 'utilities-terminal-symbolic' }),
            style_class: 'system-status-icon',
        });
        this.add_child(icon);

        this.connect('button-press-event', this._onButtonPressEvent.bind(this));
    }

    _onButtonPressEvent() {
        Main.createLookingGlass();
        Main.lookingGlass.toggle();
    }
};

// Compatibility with gnome-shell >= 3.32
if (SHELL_MINOR > 30) {
    LGIndicator = GObject.registerClass(
        { GTypeName: 'LGIndicator' },
        LGIndicator
    );
}

var indicator = null;

/* exported init */

class Extension {
    constructor() {
        log(`Inizializing ${Me.metadata.name} - Version ${Me.metadata.version}`);
    }

    enable() {
        log(`Enabling ${Me.metadata.name} - Version ${Me.metadata.version}`);

        indicator = new LGIndicator();

        Main.panel.addToStatusArea(`${Me.metadata.name} Indicator`, indicator);
    }

    disable() {
        log(`Disabling ${Me.metadata.name} - Version ${Me.metadata.version}`);

        if (indicator !== null) {
            indicator.destroy();
            indicator = null;
        }
    }
}

function init() {
    return new Extension();
}

